@@ -111,9 +111,31 @@ test_that("`.ptype = NULL` is size stable (#78)", {
 test_that("`pslide_vec()` falls back to `c()` method as required", {
   local_c_foobar()
 
-  expect_identical(pslide_vec(list(1:3, 1:3), ~foobar(.x), .ptype = foobar()), foobar(1:3))
-  expect_condition(pslide_vec(list(1:3, 1:3), ~foobar(.x), .ptype = foobar()), class = "slider_c_foobar")
+  expect_identical(pslide_vec(list(1:3, 1:3), ~foobar(.x), .ptype = foobar(integer())), foobar(1:3))
+  expect_condition(pslide_vec(list(1:3, 1:3), ~foobar(.x), .ptype = foobar(integer())), class = "slider_c_foobar")
 
   expect_identical(pslide_vec(list(1:3, 1:3), ~foobar(.x)), foobar(1:3))
   expect_condition(pslide_vec(list(1:3, 1:3), ~foobar(.x)), class = "slider_c_foobar")
 })
+
+# ------------------------------------------------------------------------------
+# .step
+
+test_that(".step produces typed `NA` values", {
+  expect_identical(pslide_int(list(1:3, 1:3), ~.x, .step = 2), c(1L, NA, 3L))
+  expect_identical(pslide_dbl(list(1:3, 1:3), ~.x, .step = 2), c(1, NA, 3))
+  expect_identical(pslide_chr(list(c("a", "b", "c"), 1:3), ~.x, .step = 2), c("a", NA, "c"))
+  expect_identical(pslide_vec(list(1:3, 1:3), ~.x, .step = 2), c(1L, NA, 3L))
+  expect_identical(pslide_vec(list(1:3, 1:3), ~.x, .step = 2, .ptype = integer()), c(1L, NA, 3L))
+})
+
+# ------------------------------------------------------------------------------
+# .complete
+
+test_that(".complete produces typed `NA` values", {
+  expect_identical(pslide_int(list(1:3, 1:3), ~1L, .before = 1, .complete = TRUE), c(NA, 1L, 1L))
+  expect_identical(pslide_dbl(list(1:3, 1:3), ~1, .before = 1, .complete = TRUE), c(NA, 1, 1))
+  expect_identical(pslide_chr(list(1:3, 1:3), ~"1", .before = 1, .complete = TRUE), c(NA, "1", "1"))
+  expect_identical(pslide_vec(list(1:3, 1:3), ~1, .before = 1, .complete = TRUE), c(NA, 1, 1))
+  expect_identical(pslide_vec(list(1:3, 1:3), ~1, .before = 1, .complete = TRUE, .ptype = integer()), c(NA, 1L, 1L))
+})
