@@ -3,36 +3,40 @@
 
 test_that("size of each `.f` result must be 1", {
   expect_error(
-    slide_period_vec(1:2, new_date(1:2), "day", ~c(.x, 1)),
+    slide_period_vec(1:2, new_date(c(1, 2)), "day", ~c(.x, 1)),
     "In iteration 1, the result of `.f` had size 2, not 1"
   )
   expect_error(
-    slide_period_dbl(1:2, new_date(1:2), "day", ~c(.x, 1)),
+    slide_period_dbl(1:2, new_date(c(1, 2)), "day", ~c(.x, 1)),
     "In iteration 1, the result of `.f` had size 2, not 1"
   )
 })
 
 test_that("inner type is allowed to be different", {
   expect_equal(
-    slide_period_vec(1:2, new_date(1:2), "day", ~if (.x == 1L) {list(1)} else {list("hi")}, .ptype = list()),
+    slide_period_vec(1:2, new_date(c(1, 2)), "day", ~if (.x == 1L) {list(1)} else {list("hi")}, .ptype = list()),
     list(1, "hi")
   )
 })
 
 test_that("inner type can be restricted with list_of", {
   expect_error(
-    slide_period_vec(1:2, new_date(1:2), "day", ~if (.x == 1L) {list_of(1)} else {list_of("hi")}, .ptype = list_of(.ptype = double())),
+    slide_period_vec(1:2, new_date(c(1, 2)), "day", ~if (.x == 1L) {list_of(1)} else {list_of("hi")}, .ptype = list_of(.ptype = double())),
     class = "vctrs_error_incompatible_type"
   )
 })
 
 test_that("type can be restricted", {
   expect_error(
-    slide_period_dbl(1:2, new_date(1:2), "day", ~if (.x == 1L) {1} else {"hi"}),
+    slide_period_dbl(1:2, new_date(c(1, 2)), "day", ~if (.x == 1L) {1} else {"hi"}),
     class = "vctrs_error_incompatible_type"
   )
 })
 
+test_that("empty input works with `.complete = TRUE` (#111)", {
+  expect_equal(slide_period_dbl(integer(), new_date(), "year", ~.x, .complete = TRUE), double())
+})
+
 # ------------------------------------------------------------------------------
 # .ptype
 
@@ -51,18 +55,18 @@ test_that("`.ptype = NULL` results in 'guessed' .ptype", {
 
 test_that("`.ptype = NULL` fails if no common type is found", {
   expect_error(
-    slide_period_vec(1:2, new_date(0:1), "day", ~ifelse(.x == 1L, "hello", 1), .ptype = NULL),
+    slide_period_vec(1:2, new_date(c(0, 1)), "day", ~ifelse(.x == 1L, "hello", 1), .ptype = NULL),
     class = "vctrs_error_incompatible_type"
   )
 })
 
 test_that("`.ptype = NULL` validates that element lengths are 1", {
   expect_error(
-    slide_period_vec(1:2, new_date(0:1), "day", ~if(.x == 1L) {1:2} else {1}, .ptype = NULL),
+    slide_period_vec(1:2, new_date(c(0, 1)), "day", ~if(.x == 1L) {1:2} else {1}, .ptype = NULL),
     "In iteration 1, the result of `.f` had size 2, not 1."
   )
   expect_error(
-    slide_period_vec(1:2, new_date(0:1), "day", ~if(.x == 1L) {NULL} else {1}, .ptype = NULL),
+    slide_period_vec(1:2, new_date(c(0, 1)), "day", ~if(.x == 1L) {NULL} else {1}, .ptype = NULL),
     "In iteration 1, the result of `.f` had size 0, not 1."
   )
 })
@@ -73,7 +77,7 @@ test_that("`.ptype = NULL` returns `NULL` with size 0 `.x`", {
 
 test_that(".ptypes with a vec_proxy() are restored to original type", {
   expect_is(
-    slide_period_vec(Sys.Date() + 1:5, new_date(1:5), "day", ~.x, .ptype = as.POSIXlt(Sys.Date())),
+    slide_period_vec(Sys.Date() + 1:5, new_date(c(1, 2, 3, 4, 5)), "day", ~.x, .ptype = as.POSIXlt(Sys.Date())),
     "POSIXlt"
   )
 })
@@ -81,7 +85,7 @@ test_that(".ptypes with a vec_proxy() are restored to original type", {
 test_that("with `.complete = TRUE`, `.ptype` is used to pad", {
   expect_equal(
     slide_period_dbl(
-      1:3, new_date(1:3),
+      1:3, new_date(c(1, 2, 3)),
       "day", ~1, .before = 1, .complete = TRUE
     ),
     c(NA, 1, 1)
@@ -91,21 +95,21 @@ test_that("with `.complete = TRUE`, `.ptype` is used to pad", {
 test_that("with `.complete = TRUE`, padding is size stable (#93)", {
   expect_equal(
     slide_period_vec(
-      1:3, new_date(1:3),
+      1:3, new_date(c(1, 2, 3)),
       "day", ~new_date(0), .before = 1, .complete = TRUE, .ptype = new_date()
     ),
     new_date(c(NA, 0, 0))
   )
   expect_equal(
     slide_period_vec(
-      1:3, new_date(1:3),
+      1:3, new_date(c(1, 2, 3)),
       "day", ~new_date(0), .after = 1, .complete = TRUE, .ptype = new_date()
     ),
     new_date(c(0, 0, NA))
   )
   expect_equal(
     slide_period_vec(
-      1:3, new_date(1:3),
+      1:3, new_date(c(1, 2, 3)),
       "day", ~new_date(0), .before = 1, .complete = TRUE, .ptype = NULL
     ),
     new_date(c(NA, 0, 0))
@@ -115,7 +119,7 @@ test_that("with `.complete = TRUE`, padding is size stable (#93)", {
 test_that("can return a matrix and rowwise bind the results together", {
   mat <- matrix(1, ncol = 2)
   expect_equal(
-    slide_period_vec(1:5, new_date(1:5), "day", ~mat, .ptype = mat),
+    slide_period_vec(1:5, new_date(c(1, 2, 3, 4, 5)), "day", ~mat, .ptype = mat),
     rbind(mat, mat, mat, mat, mat)
   )
 })
@@ -123,11 +127,11 @@ test_that("can return a matrix and rowwise bind the results together", {
 test_that("`slide_period_vec()` falls back to `c()` method as required", {
   local_c_foobar()
 
-  expect_identical(slide_period_vec(1:3, new_date(1:3), "day", ~foobar(.x), .ptype = foobar(integer())), foobar(1:3))
-  expect_condition(slide_period_vec(1:3, new_date(1:3), "day", ~foobar(.x), .ptype = foobar(integer())), class = "slider_c_foobar")
+  expect_identical(slide_period_vec(1:3, new_date(c(1, 2, 3)), "day", ~foobar(.x), .ptype = foobar(integer())), foobar(1:3))
+  expect_condition(slide_period_vec(1:3, new_date(c(1, 2, 3)), "day", ~foobar(.x), .ptype = foobar(integer())), class = "slider_c_foobar")
 
-  expect_identical(slide_period_vec(1:3, new_date(1:3), "day", ~foobar(.x)), foobar(1:3))
-  expect_condition(slide_period_vec(1:3, new_date(1:3), "day", ~foobar(.x)), class = "slider_c_foobar")
+  expect_identical(slide_period_vec(1:3, new_date(c(1, 2, 3)), "day", ~foobar(.x)), foobar(1:3))
+  expect_condition(slide_period_vec(1:3, new_date(c(1, 2, 3)), "day", ~foobar(.x)), class = "slider_c_foobar")
 })
 
 # ------------------------------------------------------------------------------
@@ -170,26 +174,26 @@ test_that("slide_period_lgl() can coerce", {
 
 test_that("slide_period_dfr() works", {
   expect_equal(
-    slide_period_dfr(1:2, new_date(1:2), "day", ~.x, .before = 1),
+    slide_period_dfr(1:2, new_date(c(1, 2)), "day", ~.x, .before = 1),
     slide_dfr(1:2, ~.x, .before = 1)
   )
 
   x <- 1:2
   expect_equal(
-    slide_period_dfr(x, new_date(1:2), "day", ~data.frame(x = .x), .before = 1),
+    slide_period_dfr(x, new_date(c(1, 2)), "day", ~data.frame(x = .x), .before = 1),
     slide_dfr(x, ~data.frame(x = .x), .before = 1)
   )
 })
 
 test_that("slide_period_dfc() works", {
   expect_equal(
-    slide_period_dfc(1:2, new_date(1:2), "day", ~.x, .before = 1),
+    slide_period_dfc(1:2, new_date(c(1, 2)), "day", ~.x, .before = 1),
     slide_dfc(1:2, ~.x, .before = 1)
   )
 
   x <- 1:2
   expect_equal(
-    slide_period_dfc(x, new_date(1:2), "day", ~data.frame(x = .x), .before = 1),
+    slide_period_dfc(x, new_date(c(1, 2)), "day", ~data.frame(x = .x), .before = 1),
     slide_dfc(x, ~data.frame(x = .x), .before = 1)
   )
 })
@@ -201,12 +205,12 @@ test_that("names exist on inner sliced elements", {
   names <- letters[1:5]
   x <- set_names(1:5, names)
   exp <- as.list(names)
-  expect_equal(slide_period_vec(x, new_date(1:5), "day", ~list(names(.x))), exp)
+  expect_equal(slide_period_vec(x, new_date(c(1, 2, 3, 4, 5)), "day", ~list(names(.x))), exp)
 })
 
 test_that("names are never placed on the output", {
   x <- set_names(1:5, letters[1:5])
-  expect_null(names(slide_period_vec(x, new_date(1:5), "day", ~.x)))
-  expect_null(names(slide_period_vec(x, new_date(1:5), "day", ~.x, .ptype = int())))
-  expect_null(names(slide_period_int(x, new_date(1:5), "day", ~.x)))
+  expect_null(names(slide_period_vec(x, new_date(c(1, 2, 3, 4, 5)), "day", ~.x)))
+  expect_null(names(slide_period_vec(x, new_date(c(1, 2, 3, 4, 5)), "day", ~.x, .ptype = int())))
+  expect_null(names(slide_period_int(x, new_date(c(1, 2, 3, 4, 5)), "day", ~.x)))
 })
